# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.2] - 2025-04-10

### Changed

- Update dependencies

## [0.1.1] - 2025-04-10

### Added

- Initial project setup
- MCP server implementation for OpenFGA
- GitHub templates and workflows
- Conventional Commits support
